@@ -2,7 +2,7 @@
 # -*- cperl -*-
 # PODNAME: beamer-reveal.pl
 # ABSTRACT: converts the .rvl file and the corresponding pdf file to a full reveal website
-our $VERSION = '20260130.1210'; # VERSION
+our $VERSION = '20260204.1417'; # VERSION
 
 
 use strict;
@@ -32,6 +32,7 @@ sub unixify;
 
 my $opt_help;
 my $opt_man;
+my $opt_debug;
 my $output_dir;
 my $aux_dir;
 my $pdf_dir;
@@ -39,6 +40,7 @@ my $pdf_dir;
 my $result = 
   GetOptions( "help"               => \$opt_help,
 	      "man"                => \$opt_man,
+	      "debug"              => \$opt_debug,
 	      "output-directory=s" => \$output_dir,
 	      "aux-directory=s"    => \$aux_dir,
 	      "pdf-directory=s"    => \$pdf_dir,
@@ -78,7 +80,7 @@ my $logger = BeamerReveal::Log->new( opening       => $openinglines,
 				     closing       => $closinglines,
 				     logfilename   => "$jobname.brlog",
 				     labelsize     => 21,
-				     activitysize  => 25 );
+				     activitysize  => 28 );
 
 ###############################
 # set defaults for directories
@@ -97,10 +99,6 @@ $logger->log( 2, "aux-files    : '$aux_dir'" );
 $logger->log( 2, "pdf-files    : '$pdf_dir'" );
 $logger->log( 2, "output-files : '$output_dir'" );
 
-my $proc_id =
-  $logger->registerTask( label    => "Slide processing",
-			 progress => 0,
-			 total    => 1 );
 my $fc_id =
   $logger->registerTask( label    => "Frame conversion",
 			 progress => 0,
@@ -109,14 +107,22 @@ my $ng_id =
   $logger->registerTask( label    => "Note generation",
 			 progress => 0,
 			 total    => 1 );
+my $proc_id =
+  $logger->registerTask( label    => "Slide processing",
+			 progress => 0,
+			 total    => 1 );
 my $mmcop_id =
   $logger->registerTask( label    => "Media copying",
 			 progress => 0,
 			 total    => 1 );
-my $mmgen_id =
+my $mmanimgen_id =
   $logger->registerTask( label    => "Animation generation",
 			 progress => 0,
 			 total    => 1 );
+my $mmstillgen_id =
+  $logger->registerTask( label    => "Still generation",
+			 progress => 0,
+			 total    => 1 );
 my $overall_id =
   $logger->registerTask( label    => "Overall progress",
 			 progress => 0,
@@ -126,11 +132,12 @@ $logger->activate();
 
 ##################
 # Read input file
-$logger->progress( $overall_id, 0, 'reading driver file' );
 
 # fetch the reveal file
 my $rvlFileName = "$aux_dir/$jobname.rvl";
 $logger->log( 0, "- Reading driver file $rvlFileName" );
+$logger->progress( $overall_id, 0, 'reading driver file' );
+
 my $rvlFile = IO::File->new();
 $rvlFile->open( "<$rvlFileName" )
   or $logger->fatal( "Error: cannot read reveal file '$rvlFileName'\n" );
@@ -156,6 +163,8 @@ for( my $i = 0; $i < @chunks; ++$i ) {
 
 #################
 # parse the file
+
+$logger->log( 0, "- Parsing driver file $rvlFileName" );
 $logger->progress( $overall_id, 1, 'parsing driver file' );
 
 my $factory = BeamerReveal->new();
@@ -163,64 +172,49 @@ my $factory = BeamerReveal->new();
 ## the first chunk needs to be a presentation chunk
 my $presentation = $factory->createFromChunk( $chunks[0], $chunksLineNrs[0] );
 
+## parse all slides
 my $slides = [];
 my $nofNotes = 0;
 eval {
   for( my $i = 1; $i < @chunks; ++$i ) {
     my $object = $factory->createFromChunk( $chunks[$i], $chunksLineNrs[$i] );
-    push @$slides, $object;
     $object->{hasnotes} = ++$nofNotes if( $object->{hasnotes} ); #if notes, add sequence number
+    push @$slides, $object;
   }
   1;
 } or do {
   $logger->fatal( "$@" );
 };
-# needed for NotesFactory
 $presentation->{parameters}->{nofnotes} = $nofNotes;
 
-
-
-######################
-# process the content
-$logger->progress( $overall_id, 2, 'processing driver file' );
-
+$logger->progress( $overall_id, 1.5, 'installing boiler plate' );
 my $mediaManager =
   BeamerReveal::MediaManager->new( $jobname,
 				   $output_dir,
 				   "${jobname}_files",
-				   $presentation->{parameters} );
+				   $presentation->{parameters},
+				   $opt_debug );
 
 # storing the reveal framework
 $logger->log( 0, "- Installing quarto/reveal.js boilerplate" );
 $mediaManager->revealToStore();
 
-# generateing the content
-$logger->log( 0, "- Processing the presentation" );
-
-my $slideCollection;
-my $i = 0;
-my $nofSlides = @$slides;
-foreach my $slide ( @$slides ) {
-  $logger->progress( $proc_id, $i++, "slide $i/$nofSlides", $nofSlides );
-  $slideCollection .= $slide->makeSlide( $i, $mediaManager, $nofNotes );
-}
-$logger->progress( $proc_id, $i );
-
 ######################
 # generate all images
-$logger->progress( $overall_id, 3, 'generating backgrounds' );
+$logger->progress( $overall_id, 2, 'generating backgrounds' );
 
 $logger->log( 0, "- Generating the images" );
-my $convertor = BeamerReveal::FrameConverter->new( "$output_dir/${jobname}_files",
-						   "$pdf_dir/$jobname.pdf",
-						   $presentation->{parameters}->{canvaswidth},
-						   $presentation->{parameters}->{canvasheight},
-						   $fc_id );
-$convertor->toJPG();
+my $frameConvertor = BeamerReveal::FrameConverter->new( "$output_dir/${jobname}_files",
+							"$pdf_dir/$jobname.pdf",
+							$presentation->{parameters}->{canvaswidth},
+							$presentation->{parameters}->{canvasheight},
+							$fc_id,
+							$opt_debug );
+$mediaManager->backgroundsToStore( $frameConvertor->toJPG() );
 
 ##########################
 # geneate the notes pages
-$logger->progress( $overall_id, 4, 'generating notes pages' );
+$logger->progress( $overall_id, 3, 'generating notes pages' );
 
 $logger->log( 0, "- Generating the notes pages" );
 if ( $nofNotes ) {
@@ -229,13 +223,39 @@ if ( $nofNotes ) {
 						      $presentation->{parameters},
 						      $presentation->{parameters}->{canvaswidth} / 2,
 						      $presentation->{parameters}->{canvasheight} / 2,
-						      $ng_id );
-  $notesFactory->toJPG();
+						      $ng_id,
+						      $opt_debug);
+  $mediaManager->notesToStore( $notesFactory->toJPG() );
 }
 else {
   $logger->progress( $ng_id, 1, 'no notes found', 1 );
 }
 
+# here's the plan:
+# - make a class 'embed' option, with possible arguments 'all', 'slides', 'slides and notes'
+# - further implement base64 encoding of slides and notes in BeamerFrame.pm
+# - still have to check all the options to the \media commands for scrutiny
+
+
+######################
+# process the content
+
+
+# generating the content
+$logger->log( 0, "- Processing the presentation" );
+$logger->progress( $overall_id, 4, 'processing presentation' );
+
+my $slideCollection;
+my $i = 0;
+my $nofSlides = @$slides;
+foreach my $slide ( @$slides ) {
+  $logger->progress( $proc_id, $i++, "slide $i/$nofSlides", $nofSlides );
+  $slideCollection .= $slide->makeSlide( $i, $mediaManager, $presentation );
+}
+$logger->progress( $proc_id, $i );
+
+
+
 ################################
 # generate the copy back-orders
 $logger->progress( $overall_id, 5, 'media copying' );
@@ -245,9 +265,15 @@ $mediaManager->processCopyBackOrders( $mmcop_id );
 
 ################################
 # generate the generation back-orders
-$logger->progress( $overall_id, 5.5, 'animation generation' );
+
+$logger->progress( $overall_id, 5.25, 'animation generation' );
+$logger->log( 0, "- Generating animations" );
+$mediaManager->processAnimationBackOrders( $mmanimgen_id );
+
+$logger->progress( $overall_id, 5.5, 'still generation' );
+$logger->log( 0, "- Generating stills" );
 $logger->log( 0, "- Generating all new media" );
-$mediaManager->processConstructionBackOrders( $mmgen_id );
+$mediaManager->processStillBackOrders( $mmstillgen_id );
 
 ######################
 # write the main file
@@ -265,13 +291,15 @@ $oFile->open( ">$oFileName" )
   or $logger->fatal( "Error: cannot write to '$oFileName'" );
 print $oFile
   BeamerReveal::TemplateStore::stampTemplate( $mainTemplate,
-					      { PRODUCER => "beamer-reveal.pl v${BeamerReveal::VERSION}",
-						TITLE    => $presentation->{parameters}->{title},
-						AUTHOR   => $presentation->{parameters}->{author},
+					      { PRODUCER  => "beamer-reveal.pl v${BeamerReveal::VERSION}",
+						TITLE     => $presentation->{parameters}->{title},
+						AUTHOR    => $presentation->{parameters}->{author},
+						AUTOSLIDE => $presentation->{parameters}->{autoslide},
+						LOOP      => $presentation->{parameters}->{loop},
 						CANVASWIDTH  => $presentation->{parameters}->{canvaswidth},
 						CANVASHEIGHT => $presentation->{parameters}->{canvasheight},
-						SLIDES   => $slideCollection,
-						SUBDIR   => "${jobname}_files" } );
+						SLIDES    => $slideCollection,
+						SUBDIR    => "${jobname}_files" } );
 $oFile->close();
 
 # finally let's create an index.html link
@@ -304,7 +332,7 @@ beamer-reveal.pl - converts the .rvl file and the corresponding pdf file to a fu
 
 =head1 VERSION
 
-version 20260130.1210
+version 20260204.1417
 
 =head1 SYNOPSIS
 
@@ -343,6 +371,10 @@ prints help message on standard output
 
 prints manual page on standard output
 
+=item B<--debug> | B<-d>
+
+runs tool in debug mode (i.e. no file cleaning in \jobname_files/meda)
+
 =item B<--output-directory> | B<-o>
 
 target directory where the reveal html files will end up in. Defaults to '.'.
