@@ -3,7 +3,7 @@
 
 
 package BeamerReveal;
-our $VERSION = '20260130.1210'; # VERSION
+our $VERSION = '20260204.1417'; # VERSION
 
 use strict;
 use warnings;
@@ -29,6 +29,13 @@ sub new {
 }
 
 
+
+sub reset {
+  my $self = shift;
+  $self->{rawpage} = 0;
+}
+
+
 sub createFromChunk {
   my $self = shift;
   my ( $chunk, $chunkStartLine ) = @_;
@@ -61,7 +68,7 @@ BeamerReveal - BeamerReveal
 
 =head1 VERSION
 
-version 20260130.1210
+version 20260204.1417
 
 =head1 SYNOPSIS
 
@@ -76,6 +83,12 @@ These objects correspond to the actual beamer to reveal conversion.
 
 Constructor
 
+=head2 reset()
+
+  $f->reset()
+
+Reset the factory for the second pass parsing
+
 =head2 createFromChunk
 
   $f->createFromChunk( $chunk, $chunkStartLine )
