@@ -3,7 +3,7 @@
 
 
 package BeamerReveal::Object::BeamerFrame;
-our $VERSION = '20260130.1210'; # VERSION
+our $VERSION = '20260204.1417'; # VERSION
 
 use parent 'BeamerReveal::Object';
 use Carp;
@@ -39,10 +39,11 @@ sub new {
   $self->{images}     = [];
   $self->{iframes}    = [];
   $self->{animations} = [];
+  $self->{stills}     = [];
   $self->{hasnotes}   = 0;
-  
+
   ++$lineCtr;
-  for( my $i = 0; $i < @$lines; ++$i ) {
+  for ( my $i = 0; $i < @$lines; ++$i ) {
     ( $lines->[$i] =~ /^-(?<command>\w+):(?<payload>.*)$/ )
       or $logger->fatal( "Error: syntax incorrect in rvl file on line $lineCtr '$lines->[$i]'\n" );
     if ( $+{command} eq 'parameters' ) {
@@ -52,27 +53,23 @@ sub new {
       # therefore not reliable
       $self->{parameters}->{rawpage} = $rawpage;
       $maxRawPage = $rawpage;
-    }
-    elsif ( $+{command} eq 'video' ) {
+    } elsif ( $+{command} eq 'video' ) {
       push @{$self->{videos}}, BeamerReveal::Object::readParameterLine( $+{payload} );
-    }
-    elsif ( $+{command} eq 'audio' ) {
+    } elsif ( $+{command} eq 'audio' ) {
       push @{$self->{audios}}, BeamerReveal::Object::readParameterLine( $+{payload} );
-    }
-    elsif ( $+{command} eq 'image' ) {
+    } elsif ( $+{command} eq 'image' ) {
       push @{$self->{images}}, BeamerReveal::Object::readParameterLine( $+{payload} );
-    }
-    elsif ( $+{command} eq 'iframe' ) {
+    } elsif ( $+{command} eq 'iframe' ) {
       push @{$self->{iframes}}, BeamerReveal::Object::readParameterLine( $+{payload} );
-    }
-    elsif ( $+{command} eq 'animation' ) {
+    } elsif ( $+{command} eq 'animation' ) {
       push @{$self->{animations}}, BeamerReveal::Object::readParameterLine( $+{payload} );
       $self->{animations}->[-1]->{tex} = $lines->[++$i];
-    }
-    elsif ( $+{command} eq 'hasnote' ) {
+    } elsif ( $+{command} eq 'still' ) {
+      push @{$self->{stills}}, BeamerReveal::Object::readParameterLine( $+{payload} );
+      $self->{stills}->[-1]->{tex} = $lines->[++$i];
+    } elsif ( $+{command} eq 'hasnote' ) {
       $self->{hasnotes} = 1;
-    }
-    else {
+    } else {
       $logger->fatal( "Error: unknown BeamerFrame data on line @{[ $lineCtr + $i ]} '$lines->[$i]'\n" );
     }
   }
@@ -86,16 +83,19 @@ sub new {
 
 sub makeSlide {
   my $self = shift;
-  my ( $i, $mediaManager, $nofNotes ) = @_;
+  my ( $i, $mediaManager, $presentation ) = @_;
 
   my $logger = $BeamerReveal::Log::logger;
   $logger->log( 2, "- making slide $i" );
   
   my $templateStore = BeamerReveal::TemplateStore->new();
   my $content = '';
+
+  my $slideEmbed =
+    exists $self->{parameters}->{embed} or exists $presentation->{parameters}->{embed};
   
-  #############################
-  # process all video material
+  ###############################################
+  # process all video material / can be embedded
   foreach my $video (@{$self->{videos}}) {
     my %commonStamps = ( X => _topercent( $video->{x} ),
 			 Y => _topercent( $video->{y} ),
@@ -112,7 +112,7 @@ sub makeSlide {
 		       );
     my $vStamps;
     my $vTemplate;
-    if( exists $video->{embed} ) {
+    if ( exists $video->{embed} or $slideEmbed ) {
       $logger->log( 4, "- adding embedded video" );
       $vTemplate = $templateStore->fetch( 'html', 'video-embedded.html' );
       my ( $mimeType, $videoContent ) = $mediaManager->videoFromStore( $video->{file},
@@ -122,8 +122,7 @@ sub makeSlide {
 		   VIDEOEMBEDDEDB64 => $videoContent,
 		   MIMETYPE         => $mimeType,
 		 };
-    }
-    else {
+    } else {
       $logger->log( 4, "- adding video" );
       $vTemplate = $templateStore->fetch( 'html', 'video.html' );
       my ( $mimeType, $videoFile ) = $mediaManager->videoFromStore( $video->{file} );
@@ -134,8 +133,8 @@ sub makeSlide {
     $content .= BeamerReveal::TemplateStore::stampTemplate( $vTemplate, $vStamps);
   }
 
-  #############################
-  # process all audio material
+  ###############################################
+  # process all audio material / can be embedded
   foreach my $audio (@{$self->{audios}}) {
     my %commonStamps = ( X => _topercent( $audio->{x} ),
 			 Y => _topercent( $audio->{y} ),
@@ -148,7 +147,7 @@ sub makeSlide {
 			 LOOP => exists $audio->{loop} ? 'loop' : '' );
     my $aStamps;
     my $aTemplate;
-    if( exists $audio->{embed} ) {
+    if ( exists $audio->{embed} or $slideEmbed ) {
       $logger->log( 4, "- adding embedded audio" );
       $aTemplate = $templateStore->fetch( 'html', 'audio-embedded.html' );
       my ( $mimeType, $audioContent ) = $mediaManager->audioFromStore( $audio->{file},
@@ -158,8 +157,7 @@ sub makeSlide {
 		   AUDIOEMBEDDEDB64 => $audioContent,
 		   MIMETYPE         => $mimeType,
 		 };
-    }
-    else {
+    } else {
       $logger->log( 4, "- adding audio" );
       $aTemplate = $templateStore->fetch( 'html', 'audio.html' );
       my ( $mimeType, $audioFile ) = $mediaManager->audioFromStore( $audio->{file} );
@@ -170,8 +168,8 @@ sub makeSlide {
     $content .= BeamerReveal::TemplateStore::stampTemplate( $aTemplate, $aStamps );
   }
 
-  #############################
-  # process all image material
+  ###############################################
+  # process all image material / can be embedded
   foreach my $image (@{$self->{images}}) {
     my %commonStamps = ( X => _topercent( $image->{x} ),
 			 Y => _topercent( $image->{y} ),
@@ -184,7 +182,7 @@ sub makeSlide {
 		       );
     my $iStamps;
     my $iTemplate;
-    if( exists $image->{embed} ) {
+    if ( exists $image->{embed} or $slideEmbed ) {
       $logger->log( 4, "- adding embedded image" );
       $iTemplate = $templateStore->fetch( 'html', 'image-embedded.html' );
       my( $mimeType, $imageContent ) = $mediaManager->imageFromStore( $image->{file},
@@ -194,8 +192,7 @@ sub makeSlide {
 		   IMAGEEMBEDDEDB64 => $imageContent,
 		   MIMETYPE         => $mimeType,
 		 };
-    }
-    else {
+    } else {
       $logger->log( 4, "- adding image" );
       $iTemplate = $templateStore->fetch( 'html', 'image.html' );
       my( $mimeType, $imageFile ) = $mediaManager->imageFromStore( $image->{file} );
@@ -206,8 +203,8 @@ sub makeSlide {
 							    $iStamps );
   }
 
-  #############################
-  # process all iframe material
+  ################################################
+  # process all iframe material / can be embedded
   foreach my $iframe (@{$self->{iframes}}) {
     my %commonStamps = ( X => _topercent( $iframe->{x} ),
 			 Y => _topercent( $iframe->{y} ),
@@ -217,7 +214,7 @@ sub makeSlide {
 		       );
     my $iStamps;
     my $iTemplate;
-    if( exists $iframe->{embed} ) {
+    if ( exists $iframe->{embed} or exists $presentation->{parameters}->{embed} ) {
       $logger->log( 4, "- adding embedded iframe" );
       $iTemplate = $templateStore->fetch( 'html', 'iframe-embedded.html' );
       my ( $mimeType, $iframeContent ) = $mediaManager->iframeFromStore( $iframe->{file},
@@ -226,8 +223,7 @@ sub makeSlide {
 		   IFRAMEID          => 'embedded-id-' . $embeddedID++,
 		   IFRAMEEMBEDDEDB64 => $iframeContent,
 		 };
-    }
-    else {
+    } else {
       $logger->log( 4, "- adding iframe" );
       $iTemplate = $templateStore->fetch( 'html', 'iframe.html' );
       my ( $mimeType, $iframeFile ) = $mediaManager->iframeFromStore( $iframe->{file} );
@@ -239,17 +235,20 @@ sub makeSlide {
 							    $iStamps );
   }
 
-  #########################
-  # process all animations
+  ##################################################
+  # process all animations / cannot yet be embedded
   foreach my $animation (@{$self->{animations}}) {
     $logger->log( 4, "- adding animation" );
+    
+    my $aTemplate;
+    my $aStamps;
 
     # 1. Generate the animation
     my $file = $mediaManager->animationFromStore( $animation );
     
     # 2. Embed it into the html
-    my $aTemplate = $templateStore->fetch( 'html', 'animation.html' );
-    my $aStamps =
+    $aTemplate = $templateStore->fetch( 'html', 'animation.html' );
+    $aStamps =
       { X => _topercent( $animation->{x} ),
 	Y => _topercent( $animation->{y} ),
 	W => _topercent( $animation->{width} ),
@@ -264,55 +263,144 @@ sub makeSlide {
 							    $aStamps );
   }
 
-  # process the frame itself  
-  my $fTemplate = $templateStore->fetch( 'html', 'beamerframe.html' );
+  ##############################################
+  # process all stills / cannot yet be embedded
+  foreach my $still (@{$self->{stills}}) {
+    $logger->log( 4, "- adding still" );
 
+    # 1. Generate the animation
+    my $file = $mediaManager->stillFromStore( $still );
+    
+    # 2. Embed it into the html
+    my $sTemplate = $templateStore->fetch( 'html', 'still.html' );
+    my $sStamps =
+      { X => _topercent( $still->{x} ),
+	Y => _topercent( $still->{y} ),
+	W => _topercent( $still->{width} ),
+	H => _topercent( $still->{height} ),
+	STILL => $file,
+	FIT       => $still->{fit}
+      };
+    $content .= BeamerReveal::TemplateStore::stampTemplate( $sTemplate,
+							    $sStamps );
+  }
+
+  ###########################
+  # process the frame itself
+
+  # title
   my $title = _modernize( $self->{parameters}->{title} );
-  if( $title =~ /\\/ ) {
+  if ( $title =~ /\\/ ) {
     $logger->fatal( "Error: the title of slide $i contains TeX-like code (observe below between <<< >>>); provide a clean version using \\frametitle[clean-version]{TeX-like code}\n" .
    		    "<<< $self->{parameters}->{title} >>>" );
-  }
-  else {
+  } else {
     $self->{parameters}->{title} = $title;
-  };
-  
+  }
+  ;
+
+  # menu entries
   my $menuTitle;
   if ( exists $self->{parameters}->{toc} ) {
-    if( $self->{parameters}->{toc} eq 'titlepage' ) {
+    if ( $self->{parameters}->{toc} eq 'titlepage' ) {
       $menuTitle = "<span class='menu-title'>%s</span>";
-    }
-    elsif( $self->{parameters}->{toc} eq 'section' ) {
+    } elsif ( $self->{parameters}->{toc} eq 'section' ) {
       $menuTitle = "<span class='menu-section'>&bull; %s</span>";
-    }
-    elsif( $self->{parameters}->{toc} eq 'subsection' ) {
+    } elsif ( $self->{parameters}->{toc} eq 'subsection' ) {
       $menuTitle = "<span class='menu-subsection'>&SmallCircle; %s</span>";
-    }
-    else {
+    } else {
       $logger->fatal( "Error: invalid toc parameter in rvl file" );
     }
-  }
-  else {
+  } else {
     $menuTitle = "<span class='menu-slide'>&bullet; %s</span>";
   }
   $menuTitle = sprintf( $menuTitle,
 			$self->{parameters}->{title} );
-  # $self->{parameters}->{truepage} );
 
-  my $slideImage = $mediaManager->slideFromStore( sprintf( 'slide-%0' . nofdigits( $maxRawPage ) . 'd.jpg',
-							   $self->{parameters}->{rawpage} ) ),;
-  my $notesImage = $mediaManager->slideFromStore( sprintf( 'notes-%0' . nofdigits( $maxNotePage ) . 'd.jpg',
-							   $self->{hasnotes} ) );
-  my $fStamps =
-    {
-     DATAMENUTITLE => $menuTitle,
-     SLIDEIMAGE   => $slideImage,
-     SLIDECONTENT => $content,
-     TRANSITION   => $self->{parameters}->{transition} || 'none',
-     NOTESIMAGE   => $self->{hasnotes} ?
-     '<img width="100%" height="100%" src="' . $notesImage . '">' : ' ' # space is important!
-    };
+  # autoSlide
+  my $autoSlide = '';
+  if( exists $self->{parameters}->{autoslide} ) {
+    $autoSlide = 'data-autoslide="' . $self->{parameters}->{autoslide} . '"';
+  }
+  
+  # notes
+  my $notes = ' '; # the space is important as default, if you remove it, the notes will be sticky!
 
-  return BeamerReveal::TemplateStore::stampTemplate( $fTemplate, $fStamps );
+  if ( $self->{hasnotes} ) {
+    if ( $slideEmbed ) {
+      my $nTemplate = $templateStore->fetch( 'html', 'note-embedded.html' );
+      
+      # remember: the hasnote entry holds the note number
+      my ( $mimeType, $notesImage ) = $mediaManager->noteFromStore( $self->{hasnotes},
+								to_embed => 1 );
+      
+      my $nStamps =
+	{
+	 NOTEID          => 'embedded-id-' . $embeddedID++,
+	 NOTEEMBEDDEDB64 => $notesImage,	
+	 MIMETYPE        => $mimeType,
+	};
+      
+      $notes = BeamerReveal::TemplateStore::stampTemplate( $nTemplate, $nStamps );
+    }
+    else {
+      my $nTemplate = $templateStore->fetch( 'html', 'note.html' );
+      
+      # remember: the hasnote entry holds the note number
+      my ( undef, $notesImage ) = $mediaManager->noteFromStore( $self->{hasnotes} );
+      
+      my $nStamps =
+	{
+	 NOTESIMAGE   => $notesImage
+	};
+      
+      $notes = BeamerReveal::TemplateStore::stampTemplate( $nTemplate, $nStamps );
+    }
+  }
+
+  # generate slide itself
+  if ( $slideEmbed ) {
+    my $fTemplate = $templateStore->fetch( 'html', 'beamerframe-embedded.html' );
+    
+    my ( $mimeType, $slideImage ) = $mediaManager->slideFromStore( $self->{parameters}->{rawpage},
+								   to_embed => 1 );
+
+    # remember: the hasnote entry holds the note number
+    my ( undef, $notesImage ) = $mediaManager->noteFromStore( $self->{hasnotes} );
+
+    my $fStamps =
+      {
+       DATAMENUTITLE    => $menuTitle,
+       SLIDEID          => 'embedded-id-' . $embeddedID++,
+       SLIDEEMBEDDEDB64 => $slideImage,
+       MIMETYPE         => $mimeType,
+       SLIDECONTENT     => $content,
+       TRANSITION       => $self->{parameters}->{transition} || 'fade',
+       AUTOSLIDE        => $autoSlide,
+       NOTESIMAGE       => $notes
+      };
+    
+    return BeamerReveal::TemplateStore::stampTemplate( $fTemplate, $fStamps );
+    
+  } else {
+    my $fTemplate = $templateStore->fetch( 'html', 'beamerframe.html' );
+    
+    my ( undef, $slideImage ) = $mediaManager->slideFromStore( $self->{parameters}->{rawpage} );
+    
+    # remember: the hasnote entry holds the note number
+    my ( undef, $notesImage ) = $mediaManager->noteFromStore( $self->{hasnotes} );
+    
+    my $fStamps =
+      {
+       DATAMENUTITLE => $menuTitle,
+       SLIDEIMAGE    => $slideImage,
+       SLIDECONTENT  => $content,
+       TRANSITION    => $self->{parameters}->{transition} || 'fade',
+       AUTOSLIDE     => $autoSlide,
+       NOTESIMAGE    => $notes
+      };
+    
+    return BeamerReveal::TemplateStore::stampTemplate( $fTemplate, $fStamps );
+  }
 }
 
 sub _topercent {
@@ -380,7 +468,7 @@ sub _modernize {
 		    qr/\\OE/ => 'Œ',
 		    qr/\\&/ => '&',
 		   };
-  while( my ( $regexp, $rep ) = each ( %$dictionary ) ) {
+  while ( my ( $regexp, $rep ) = each ( %$dictionary ) ) {
     $string =~ s/$regexp/$rep/g;
   }
   return $string;
@@ -400,7 +488,7 @@ BeamerReveal::Object::BeamerFrame - BeamerFrame object
 
 =head1 VERSION
 
-version 20260130.1210
+version 20260204.1417
 
 =head1 SYNOPSIS
 
